==> owncloud-8.2.5.tar.bz2: owncloud/core/l10n/es_MX.js <==
OC.L10N.register(
    "core",
    {
    "Couldn't send mail to following users: %s " : "No se pudo enviar el mensaje a los siguientes usuarios: %s",
    "Turned on maintenance mode" : "Modo mantenimiento activado",
    "Turned off maintenance mode" : "Modo mantenimiento desactivado",
    "Updated database" : "Base de datos actualizada",
    "No image or file provided" : "No se especificó ningún archivo o imagen",
    "Unknown filetype" : "Tipo de archivo desconocido",
    "Invalid image" : "Imagen inválida",
    "No temporary profile picture available, try again" : "No hay disponible una imagen temporal de perfil, pruebe de nuevo",
    "No crop data provided" : "No se proporcionó datos del recorte",
    "Sunday" : "Domingo",
    "Monday" : "Lunes",
    "Tuesday" : "Martes",
    "Wednesday" : "Miércoles",
    "Thursday" : "Jueves",
    "Friday" : "Viernes",
    "Saturday" : "Sábado",
    "Sun." : "Dom.",
    "Mon." : "Lun.",
    "Tue." : "Mar.",
    "Wed." : "Mier.",
    "Thu." : "Jue.",
    "Fri." : "Vie.",
    "Sat." : "Sab.",
    "January" : "Enero",
    "February" : "Febrero",
    "March" : "Marzo",
    "April" : "Abril",
    "May" : "Mayo",
    "June" : "Junio",
    "July" : "Julio",
    "August" : "Agosto",
    "September" : "Septiembre",
    "October" : "Octubre",
    "November" : "Noviembre",
    "December" : "Diciembre",
    "Jan." : "Ene.",
    "Feb." : "Feb.",
    "Mar." : "Mar.",
    "Apr." : "Abr.",
    "May." : "May.",
    "Jun." : "Jun.",
    "Jul." : "Jul.",
    "Aug." : "Ago.",
    "Sep." : "Sep.",
    "Oct." : "Oct.",
    "Nov." : "Nov.",
    "Dec." : "Dic.",
    "Settings" : "Ajustes",
    "Saving..." : "Guardando...",
    "seconds ago" : "hace segundos",
    "No" : "No",
    "Yes" : "Sí",
    "Choose" : "Seleccionar",
    "Error loading file picker template: {error}" : "Error cargando plantilla del seleccionador de archivos: {error}",
    "Ok" : "Aceptar",
    "Error loading message template: {error}" : "Error cargando plantilla del mensaje: {error}",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} conflicto de archivo","{count} conflictos de archivo"],
    "One file conflict" : "Un conflicto de archivo",
    "Which files do you want to keep?" : "¿Que archivos deseas mantener?",
    "If you select both versions, the copied file will have a number added to its name." : "Si seleccionas ambas versiones, el archivo copiado tendrá añadido un número en su nombre.",
    "Cancel" : "Cancelar",
    "Continue" : "Continuar",
    "(all selected)" : "(todos seleccionados)",
    "({count} selected)" : "({count} seleccionados)",
    "Error loading file exists template" : "Error cargando plantilla de archivo existente",
    "Shared" : "Compartido",
    "Error" : "Error",
    "Error while sharing" : "Error al compartir",
    "Error while unsharing" : "Error al dejar de compartir",
    "Error while changing permissions" : "Error al cambiar permisos",
    "Error setting expiration date" : "Error estableciendo fecha de caducidad",
    "Set expiration date" : "Establecer fecha de caducidad",
    "Expiration" : "Caducidad",
    "Expiration date" : "Fecha de caducidad",
    "Sending ..." : "Enviando...",
    "Email sent" : "Correo electrónico enviado",
    "Resharing is not allowed" : "No se permite compartir de nuevo",
    "Share link" : "Enlace compartido",
    "Password protect" : "Protección con contraseña",
    "Password" : "Contraseña",
    "Email link to person" : "Enviar enlace por correo electrónico a una persona",
    "Send" : "Enviar",
    "Shared with you and the group {group} by {owner}" : "Compartido contigo y el grupo {group} por {owner}",
    "Shared with you by {owner}" : "Compartido contigo por {owner}",
    "Shared in {item} with {user}" : "Compartido en {item} con {user}",
    "group" : "grupo",
    "notify by email" : "notificar al usuario por correo electrónico",
    "Unshare" : "Dejar de compartir",
    "can share" : "puede compartir",
    "can edit" : "puede editar",
    "create" : "crear",
    "delete" : "eliminar",
    "access control" : "control de acceso",
    "Share" : "Compartir",
    "Warning" : "Precaución",
    "The object type is not specified." : "El tipo de objeto no está especificado.",
    "Enter new" : "Ingresar nueva",
    "Delete" : "Eliminar",
    "Add" : "Agregar",
    "Edit tags" : "Editar etiquetas",
    "Error loading dialog template: {error}" : "Error cargando plantilla de diálogo: {error}",
    "No tags selected for deletion." : "No hay etiquetas seleccionadas para borrar.",
    "Please reload the page." : "Vuelva a cargar la página.",
    "The update was successful. Redirecting you to ownCloud now." : "La actualización se ha realizado con éxito. Redireccionando a ownCloud ahora.",
    "%s password reset" : "%s restablecer contraseña",
    "Use the following link to reset your password: {link}" : "Utilice el siguiente enlace para restablecer su contraseña: {link}",
    "New password" : "Nueva contraseña",
    "Reset password" : "Restablecer contraseña",
    "Personal" : "Personal",
    "Users" : "Usuarios",
    "Apps" : "Aplicaciones",
    "Admin" : "Administración",
    "Help" : "Ayuda",
    "Error loading tags" : "Error cargando etiquetas.",
    "Tag already exists" : "La etiqueta ya existe",
    "Error deleting tag(s)" : "Error borrando etiqueta(s)",
    "Error tagging" : "Error al etiquetar",
    "Error untagging" : "Error al quitar etiqueta",
    "Error favoriting" : "Error al marcar como favorito",
    "Error unfavoriting" : "Error al quitar como favorito",
    "Access forbidden" : "Acceso denegado",
    "Hey there,\n\njust letting you know that %s shared %s with you.\nView it: %s\n\n" : "Hola:\n\nTan solo queremos informarte que %s compartió %s contigo.\nMíralo aquí: %s\n\n",
    "The share will expire on %s." : "El objeto dejará de ser compartido el %s.",
    "Cheers!" : "¡Saludos!",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Su directorio de datos y sus archivos probablemente sean accesibles a través de internet ya que el archivo .htaccess no funciona.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\">documentation</a>." : "Para información de cómo configurar apropiadamente su servidor, por favor vea la <a href=\"%s\" target=\"_blank\">documentación</a>.",
    "Create an <strong>admin account</strong>" : "Crear una <strong>cuenta de administrador</strong>",
    "Username" : "Nombre de usuario",
    "Data folder" : "Directorio de datos",
    "Configure the database" : "Configurar la base de datos",
    "Database user" : "Usuario de la base de datos",
    "Database password" : "Contraseña de la base de datos",
    "Database name" : "Nombre de la base de datos",
    "Database tablespace" : "Espacio de tablas de la base de datos",
    "Database host" : "Host de la base de datos",
    "Finish setup" : "Completar la instalación",
    "Finishing …" : "Finalizando …",
    "Log out" : "Salir",
    "Search" : "Buscar",
    "Server side authentication failed!" : "La autenticación a fallado en el servidor.",
    "Please contact your administrator." : "Por favor, contacte con el administrador.",
    "Log in" : "Entrar",
    "remember" : "recordar",
    "Alternative Logins" : "Accesos Alternativos",
    "This ownCloud instance is currently in single user mode." : "Esta instalación de ownCloud se encuentra en modo de usuario único.",
    "This means only administrators can use the instance." : "Esto quiere decir que solo un administrador puede usarla.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Contacte con su administrador de sistemas si este mensaje persiste o aparece de forma inesperada.",
    "Thank you for your patience." : "Gracias por su paciencia."
},
"nplurals=2; plural=(n != 1);");

==> owncloud-10.0.8.tar.bz2: owncloud/core/l10n/es_MX.js <==
OC.L10N.register(
    "core",
    {
    "Please select a file." : "Por favor selecciona un archivo.",
    "File is too big" : "El archivo es demasiado grande",
    "Invalid file provided" : "Archivo inválido",
    "No image or file provided" : "No se especificó ningún archivo o imagen",
    "Unknown filetype" : "Tipo de archivo desconocido",
    "Invalid image" : "Imagen inválida",
    "An error occurred. Please contact your admin." : "Ocurrió un error. Por favor contacta a tu administrador.",
    "No temporary profile picture available, try again" : "No hay disponible una imagen temporal de perfil, pruebe de nuevo",
    "No crop data provided" : "No se proporcionó datos del recorte",
    "No valid crop data provided" : "No hay datos de recorte válidos",
    "Crop is not square" : "Recorte no es cuadrado",
    "Couldn't reset password because the token is invalid" : "No se pudo restablecer la contraseña por que el token es inválido",
    "Couldn't reset password because the token is expired" : "No se pudo restablecer la contraseña por que el token ha expirado",
    "%s password reset" : "%s restablecer contraseña",
    "Couldn't send reset email. Please contact your administrator." : "No se pudo enviar correo de restauración de contraseña. Por favor contacta a tu administrador.",
    "Couldn't send mail to following users: %s " : "No se pudo enviar el mensaje a los siguientes usuarios: %s",
    "Preparing update" : "Preparando actualización",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Repair warning: " : "Alerta de reparación:",
    "Repair error: " : "Error de reparación:",
    "Please use the command line updater because automatic updating is disabled in the config.php." : "Por favor usa el actualizador de línea de comandos porque las actualizaciones automáticas están deshabilitadas en el config.php.",
    "[%d / %d]: Checking table %s" : "[%d / %d]: Revisando la tabla %s",
    "Turned on maintenance mode" : "Modo mantenimiento activado",
    "Turned off maintenance mode" : "Modo mantenimiento desactivado",
    "Maintenance mode is kept active" : "El modo de mantenimiento sigue activo",
    "Updating database schema" : "Actualizando esquema de la base de datos",
    "Updated database" : "Base de datos actualizada",
    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "Verificando si el esquema de la base de datos puede ser actualizado (esto puede llevar tiempo dependiendo del tamaño de la base de datos)",
    "Checking updates of apps" : "Revisando actualizaciones de las aplicaciones",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Verificando si el esquema de la base de datos para %s puede ser actualizado (esto puede llevar tiempo dependiendo del tamaño de la base de datos)",
    "Set log level to debug" : "Se estableció nivel del registro a depuración",
    "Already up to date" : "Ya se encuentra actualizado",
    "Sunday" : "Domingo",
    "Monday" : "Lunes",
    "Tuesday" : "Martes",
    "Wednesday" : "Miércoles",
    "Thursday" : "Jueves",
    "Friday" : "Viernes",
    "Saturday" : "Sábado",
    "Sun." : "Dom.",
    "Mon." : "Lun.",
    "Tue." : "Mar.",
    "Wed." : "Mier.",
    "Thu." : "Jue.",
    "Fri." : "Vie.",
    "Sat." : "Sab.",
    "January" : "Enero",
    "February" : "Febrero",
    "March" : "Marzo",
    "April" : "Abril",
    "May" : "Mayo",
    "June" : "Junio",
    "July" : "Julio",
    "August" : "Agosto",
    "September" : "Septiembre",
    "October" : "Octubre",
    "November" : "Noviembre",
    "December" : "Diciembre",
    "Jan." : "Ene.",
    "Feb." : "Feb.",
    "Mar." : "Mar.",
    "Apr." : "Abr.",
    "May." : "May.",
    "Jun." : "Jun.",
    "Jul." : "Jul.",
    "Aug." : "Ago.",
    "Sep." : "Sep.",
    "Oct." : "Oct.",
    "Nov." : "Nov.",
    "Dec." : "Dic.",
    "Settings" : "Ajustes",
    "Saving..." : "Guardando...",
    "seconds ago" : "hace segundos",
    "No" : "No",
    "Yes" : "Sí",
    "Choose" : "Seleccionar",
    "Error loading file picker template: {error}" : "Error cargando plantilla del seleccionador de archivos: {error}",
    "Ok" : "Aceptar",
    "Error loading message template: {error}" : "Error cargando plantilla del mensaje: {error}",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} conflicto de archivo","{count} conflictos de archivo"],
    "One file conflict" : "Un conflicto de archivo",
    "Which files do you want to keep?" : "¿Que archivos deseas mantener?",
    "If you select both versions, the copied file will have a number added to its name." : "Si seleccionas ambas versiones, el archivo copiado tendrá añadido un número en su nombre.",
    "Cancel" : "Cancelar",
    "Continue" : "Continuar",
    "(all selected)" : "(todos seleccionados)",
    "({count} selected)" : "({count} seleccionados)",
    "Error loading file exists template" : "Error cargando plantilla de archivo existente",
    "Shared" : "Compartido",
    "Error" : "Error",
    "Error while sharing" : "Error al compartir",
    "Error while unsharing" : "Error al dejar de compartir",
    "Set expiration date" : "Establecer fecha de caducidad",
    "Expiration" : "Caducidad",
    "Expiration date" : "Fecha de caducidad",
    "Remove link" : "Eliminar enlace",
    "Link" : "Enlace",
    "Edit" : "Editar",
    "Remove" : "Borrar",
    "Choose a password for the public link" : "Establece una contraseña para el enlace público",
    "Filename" : "Nombre de archivo",
    "Password" : "Contraseña",
    "Name" : "Nombre",
    "Allow editing" : "Permitir edición",
    "Save" : "Guardar",
    "Sending ..." : "Enviando...",
    "Email sent" : "Correo electrónico enviado",
    "Email link to person" : "Enviar enlace por correo electrónico a una persona",
    "Shared with you and the group {group} by {owner}" : "Compartido contigo y el grupo {group} por {owner}",
    "Shared with you by {owner}" : "Compartido contigo por {owner}",
    "group" : "grupo",
    "remote" : "remoto",
    "notify by email" : "notificar al usuario por correo electrónico",
    "Unshare" : "Dejar de compartir",
    "can share" : "puede compartir",
    "can edit" : "puede editar",
    "create" : "crear",
    "change" : "cambio",
    "delete" : "eliminar",
    "access control" : "control de acceso",
    "Share" : "Compartir",
    "Resharing is not allowed" : "No se permite compartir de nuevo",
    "Warning" : "Precaución",
    "restricted" : "restringido",
    "invisible" : "invisible",
    "({scope})" : "({scope})",
    "Delete" : "Eliminar",
    "Rename" : "Renombrar",
    "The object type is not specified." : "El tipo de objeto no está especificado.",
    "Enter new" : "Ingresar nueva",
    "Add" : "Agregar",
    "Edit tags" : "Editar etiquetas",
    "Error loading dialog template: {error}" : "Error cargando plantilla de diálogo: {error}",
    "No tags selected for deletion." : "No hay etiquetas seleccionadas para borrar.",
    "Please reload the page." : "Vuelva a cargar la página.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud community</a>." : "La actualización ha fracasado. Por favor, informe de este problema a la <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">Comunidad de ownCloud</a>.",
    "The update was successful. Redirecting you to ownCloud now." : "La actualización se ha realizado con éxito. Redireccionando a ownCloud ahora.",
    "Personal" : "Personal",
    "Users" : "Usuarios",
    "Apps" : "Aplicaciones",
    "Admin" : "Administración",
    "Help" : "Ayuda",
    "Access forbidden" : "Acceso denegado",
    "File not found" : "Archivo no encontrado",
    "Hey there,\n\njust letting you know that %s shared %s with you.\nView it: %s\n\n" : "Hola:\n\nTan solo queremos informarte que %s compartió %s contigo.\nMíralo aquí: %s\n\n",
    "The share will expire on %s." : "El objeto dejará de ser compartido el %s.",
    "Cheers!" : "¡Saludos!",
    "Technical details" : "Detalles técnnicos",
    "Remote Address: %s" : "Dirección Remota: %s",
    "Request ID: %s" : "ID de Solicitud: %s",
    "Type: %s" : "Tipo: %s",
    "Code: %s" : "Código: %s",
    "Message: %s" : "Mensaje: %s",
    "File: %s" : "Archivo: %s",
    "Line: %s" : "Línea: %s",
    "Create an <strong>admin account</strong>" : "Crear una <strong>cuenta de administrador</strong>",
    "Username" : "Nombre de usuario",
    "Data folder" : "Directorio de datos",
    "Configure the database" : "Configurar la base de datos",
    "Database user" : "Usuario de la base de datos",
    "Database password" : "Contraseña de la base de datos",
    "Database name" : "Nombre de la base de datos",
    "Database tablespace" : "Espacio de tablas de la base de datos",
    "Database host" : "Host de la base de datos",
    "Finish setup" : "Completar la instalación",
    "Finishing …" : "Finalizando …",
    "Log out" : "Salir",
    "Search" : "Buscar",
    "Server side authentication failed!" : "La autenticación a fallado en el servidor.",
    "Please contact your administrator." : "Por favor, contacte con el administrador.",
    "Log in" : "Entrar",
    "Alternative Logins" : "Accesos Alternativos",
    "Use the following link to reset your password: {link}" : "Utilice el siguiente enlace para restablecer su contraseña: {link}",
    "New password" : "Nueva contraseña",
    "Reset password" : "Restablecer contraseña",
    "This ownCloud instance is currently in single user mode." : "Esta instalación de ownCloud se encuentra en modo de usuario único.",
    "This means only administrators can use the instance." : "Esto quiere decir que solo un administrador puede usarla.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Contacte con su administrador de sistemas si este mensaje persiste o aparece de forma inesperada.",
    "Thank you for your patience." : "Gracias por su paciencia.",
    "Copy to clipboard" : "Copiar al portapapeles",
    "Anyone with the link has access to the file/folder" : "Cualquier persona con el enlace tiene acceso al archivo/carpeta",
    "Link name" : "Nombre del enlace"
},
"nplurals=2; plural=(n != 1);");
